#ifndef PYTHONIC_INCLUDE_OPERATOR_LSHIFT__HPP
#define PYTHONIC_INCLUDE_OPERATOR_LSHIFT__HPP

#include "pythonic/include/operator_/lshift.hpp"

PYTHONIC_NS_BEGIN

namespace operator_
{
  USING_FUNCTOR(__lshift__, lshift);
}
PYTHONIC_NS_END

#endif
