#ifndef PYTHONIC_INCLUDE_NUMPY_SOMETRUE_HPP
#define PYTHONIC_INCLUDE_NUMPY_SOMETRUE_HPP

#include "pythonic/include/numpy/any.hpp"

PYTHONIC_NS_BEGIN

namespace numpy
{
  USING_FUNCTOR(sometrue, any);
}
PYTHONIC_NS_END

#endif
